@@ -42,24 +42,16 @@ struct _SnapdClientClass
     void (* _snapd_reserved4) (void);
 };
 
-typedef enum
-{  
-    SNAPD_ERROR_CONNECTION_FAILED,
-    SNAPD_ERROR_WRITE_ERROR,
-    SNAPD_ERROR_READ_ERROR,
-    SNAPD_ERROR_PARSE_ERROR,
-    SNAPD_ERROR_GENERAL_ERROR,
-    SNAPD_ERROR_LOGIN_REQUIRED,
-    SNAPD_ERROR_INVALID_AUTH_DATA,  
-    SNAPD_ERROR_TWO_FACTOR_REQUIRED,
-    SNAPD_ERROR_TWO_FACTOR_FAILED,
-    SNAPD_ERROR_BAD_REQUEST,
-    SNAPD_ERROR_PERMISSION_DENIED,
-    SNAPD_ERROR_LAST
-} SnapdError;
-
-#define SNAPD_ERROR snapd_error_quark ()
-
+/**
+ * SnapdFindFlags:
+ * @SNAPD_FIND_FLAGS_NONE: No flags, default behaviour
+ * @SNAPD_FIND_FLAGS_MATCH_NAME: Search for snaps whose name matches the given
+ *     string. The match is exact unless the string ends in *.
+ * @SNAPD_FIND_FLAGS_SELECT_PRIVATE: Search private snaps
+ * @SNAPD_FIND_FLAGS_SELECT_REFRESH: Search refreshable snaps
+ *
+ * Flag to change how a find is performed.
+ */
 typedef enum
 {
     SNAPD_FIND_FLAGS_NONE            = 0,
@@ -74,32 +66,25 @@ typedef enum
  * @main_task: a #SnapdTask describing the overall task in progress
  * @tasks: (element-type SnapdTask): tasks to be done / being done.
  * @user_data: user data passed to the callback
+ *
+ * Signature for callback function used in
+ * snapd_client_connect_interface_sync(),
+ * snapd_client_disconnect_interface_async(),
+ * snapd_client_install_sync(),
+ * snapd_client_refresh_sync(),
+ * snapd_client_remove_sync(),
+ * snapd_client_enable_sync() and
+ * snapd_client_disable_sync().
  */
 typedef void (*SnapdProgressCallback) (SnapdClient *client, SnapdTask *main_task, GPtrArray *tasks, gpointer user_data);
 
-GQuark                  snapd_error_quark                          (void) G_GNUC_CONST;
-
-SnapdAuthData          *snapd_login_sync                           (const gchar          *username,
-                                                                    const gchar          *password,
-                                                                    const gchar          *otp,
-                                                                    GCancellable         *cancellable,
-                                                                    GError              **error);
-void                    snapd_login_async                          (const gchar          *username,
-                                                                    const gchar          *password,
-                                                                    const gchar          *otp,
-                                                                    GCancellable         *cancellable,
-                                                                    GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
-SnapdAuthData          *snapd_login_finish                         (GAsyncResult         *result,
-                                                                    GError              **error);
-
 SnapdClient            *snapd_client_new                           (void);
 
 gboolean                snapd_client_connect_sync                  (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
 
-gboolean                snapd_client_login_sync                    (SnapdClient          *client,
+SnapdAuthData          *snapd_client_login_sync                    (SnapdClient          *client,
                                                                     const gchar          *username,
                                                                     const gchar          *password,
                                                                     const gchar          *otp,
@@ -112,7 +97,7 @@ void                    snapd_client_login_async                   (SnapdClient
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
                                                                     gpointer              user_data);
-gboolean                snapd_client_login_finish                  (SnapdClient          *client,
+SnapdAuthData         *snapd_client_login_finish                  (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
@@ -335,6 +320,7 @@ gboolean                snapd_client_disable_finish                (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
+#ifdef SNAPD_BUY_SUPPORT
 GPtrArray              *snapd_client_get_payment_methods_sync      (SnapdClient          *client,
                                                                     gboolean             *allows_automatic_payment,
                                                                     GCancellable         *cancellable,
@@ -364,6 +350,7 @@ void                    snapd_client_buy_async                     (SnapdClient
 gboolean                snapd_client_buy_finish                    (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
+#endif
 
 G_END_DECLS
 
