@@ -16,37 +16,6 @@
 /* enumerations from "./snapd-client.h" */
 #include "./snapd-client.h"
 
-GType
-snapd_error_get_type (void)
-{
-  static volatile gsize g_enum_type_id__volatile = 0;
-
-  if (g_once_init_enter (&g_enum_type_id__volatile))
-    {
-      static const GEnumValue values[] = {
-        { SNAPD_ERROR_CONNECTION_FAILED, "SNAPD_ERROR_CONNECTION_FAILED", "connection-failed" },
-        { SNAPD_ERROR_WRITE_ERROR, "SNAPD_ERROR_WRITE_ERROR", "write-error" },
-        { SNAPD_ERROR_READ_ERROR, "SNAPD_ERROR_READ_ERROR", "read-error" },
-        { SNAPD_ERROR_PARSE_ERROR, "SNAPD_ERROR_PARSE_ERROR", "parse-error" },
-        { SNAPD_ERROR_GENERAL_ERROR, "SNAPD_ERROR_GENERAL_ERROR", "general-error" },
-        { SNAPD_ERROR_LOGIN_REQUIRED, "SNAPD_ERROR_LOGIN_REQUIRED", "login-required" },
-        { SNAPD_ERROR_INVALID_AUTH_DATA, "SNAPD_ERROR_INVALID_AUTH_DATA", "invalid-auth-data" },
-        { SNAPD_ERROR_TWO_FACTOR_REQUIRED, "SNAPD_ERROR_TWO_FACTOR_REQUIRED", "two-factor-required" },
-        { SNAPD_ERROR_TWO_FACTOR_FAILED, "SNAPD_ERROR_TWO_FACTOR_FAILED", "two-factor-failed" },
-        { SNAPD_ERROR_BAD_REQUEST, "SNAPD_ERROR_BAD_REQUEST", "bad-request" },
-        { SNAPD_ERROR_PERMISSION_DENIED, "SNAPD_ERROR_PERMISSION_DENIED", "permission-denied" },
-        { SNAPD_ERROR_LAST, "SNAPD_ERROR_LAST", "last" },
-        { 0, NULL, NULL }
-      };
-
-      GType g_enum_type_id =
-        g_enum_register_static (g_intern_static_string ("SnapdError"), values);
-
-      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
-    }
-
-  return g_enum_type_id__volatile;
-}
 GType
 snapd_find_flags_get_type (void)
 {
@@ -71,6 +40,40 @@ snapd_find_flags_get_type (void)
   return g_enum_type_id__volatile;
 }
 
+/* enumerations from "./snapd-error.h" */
+#include "./snapd-error.h"
+
+GType
+snapd_error_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { SNAPD_ERROR_CONNECTION_FAILED, "SNAPD_ERROR_CONNECTION_FAILED", "connection-failed" },
+        { SNAPD_ERROR_WRITE_FAILED, "SNAPD_ERROR_WRITE_FAILED", "write-failed" },
+        { SNAPD_ERROR_READ_FAILED, "SNAPD_ERROR_READ_FAILED", "read-failed" },
+        { SNAPD_ERROR_BAD_REQUEST, "SNAPD_ERROR_BAD_REQUEST", "bad-request" },
+        { SNAPD_ERROR_BAD_RESPONSE, "SNAPD_ERROR_BAD_RESPONSE", "bad-response" },
+        { SNAPD_ERROR_AUTH_DATA_REQUIRED, "SNAPD_ERROR_AUTH_DATA_REQUIRED", "auth-data-required" },
+        { SNAPD_ERROR_AUTH_DATA_INVALID, "SNAPD_ERROR_AUTH_DATA_INVALID", "auth-data-invalid" },
+        { SNAPD_ERROR_TWO_FACTOR_REQUIRED, "SNAPD_ERROR_TWO_FACTOR_REQUIRED", "two-factor-required" },
+        { SNAPD_ERROR_TWO_FACTOR_INVALID, "SNAPD_ERROR_TWO_FACTOR_INVALID", "two-factor-invalid" },
+        { SNAPD_ERROR_PERMISSION_DENIED, "SNAPD_ERROR_PERMISSION_DENIED", "permission-denied" },
+        { SNAPD_ERROR_FAILED, "SNAPD_ERROR_FAILED", "failed" },
+        { 0, NULL, NULL }
+      };
+
+      GType g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("SnapdError"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+
 /* enumerations from "./snapd-snap.h" */
 #include "./snapd-snap.h"
 
